@@ -66,55 +66,74 @@ class Commit:
         flags=re.IGNORECASE,
     )
 
+    group_types = {
+        'build': 'build',
+        'chore': 'build',
+        'ci': 'ci',
+        'doc': 'docs',
+        'docs': 'docs',
+        'feat': 'feat',
+        'feature': 'feat',
+        'features': 'feat',
+        'fix': 'fix',
+        'fixes': 'fix',
+        'perf': 'perf',
+        'performance': 'perf',
+        'refac': 'refactor',
+        'refactor': 'refactor',
+        'revert': 'revert',
+        'test': 'test',
+    }
+
     def __init__(self, commit_dict):
-        self.commit_dict = commit_dict
+        # add items in dictionary to class
+        for key, value in commit_dict.items():
+            setattr(self, key, value)
 
-    def __getattr__(self, name):
+        # parse commit title for commit-it-simple parameters
+        result = Commit.commit_regex.match(self.title)
+        self._breaking = result.group('breaking')
+        self._commit_type = result.group('type')
+        self._scope = result.group('scope')
+        self._description = result.group('description')
+        self._description_alt = result.group('description_alt')
 
+    @property
+    def breaking(self):
+        return self._breaking
+
+    @property
+    def commit_type(self):
+        """Group equivalent commit types."""
         try:
-            return self.commit_dict[name]
+            return Commit.group_types[self._commit_type]
         except KeyError:
+            # if commit type group not specified, return raw commit type
+            return self._commit_type if self._commit_type is not None else 'other'
 
-            result = Commit.commit_regex.match(self.title)
-            breaking, commit_type, scope, description, description_alt = (
-                result.group('breaking'),
-                result.group('type'),
-                result.group('scope'),
-                result.group('description'),
-                result.group('description_alt'),
-            )
+    @property
+    def description(self):
+        return (
+            self._description
+            if self._description is not None
+            else self._description_alt
+        )
 
-            if name == 'description':
-                return description if description is not None else description_alt
-            elif name == 'is_breaking':
-                return breaking is not None
-            elif name == 'type':
-                # group equivalent commit types
-                types = {
-                    'doc': 'docs',
-                    'docs': 'docs',
-                    'feat': 'feat',
-                    'feature': 'feat',
-                    'features': 'feat',
-                    'fix': 'fix',
-                    'fixes': 'fix',
-                    'perf': 'perf',
-                    'performance': 'perf',
-                    'refac': 'refactor',
-                    'refactor': 'refactor',
-                }
-                try:
-                    return types[commit_type]
-                except KeyError:
-                    return commit_type if commit_type is not None else 'other'
-            elif name == 'scope':
-                return scope
-            elif name == 'is_feature':
-                return "feat" in self.type.lower()
-            elif name == 'is_fix':
-                return "fix" in self.type.lower()
-            else:
-                raise AttributeError(f"Attribute '{name}' not found in class Commit")
+    @property
+    def scope(self):
+        return self._scope
+
+    @property
+    def is_breaking(self):
+        return self.breaking is not None
+
+    @property
+    def is_feature(self):
+        return "feat" in self.commit_type.lower()
+
+    @property
+    def is_fix(self):
+        return "fix" in self.commit_type.lower()
 
     def __repr__(self):
         return (
@@ -190,7 +209,19 @@ def calculate_next(versions, prefix=""):
             return f"{prefix}{major}.{minor}.{patch}"
 
 
-def compile_log(commits):
+def _is_valid_version(tag, prefix=""):
+    """Check if the provided tag is a version number."""
+
+    tag = tag[len(prefix) :]  # subtring the tag by prefix length
+    result = semver_regex.match(tag)
+
+    if result is None:
+        return False
+    else:
+        return True
+
+
+def compile_log(commits, prefix=""):
     """Iterate though a list of Commits, compiling a list of Versions based on tags."""
     versions = []
 
@@ -199,9 +230,12 @@ def compile_log(commits):
     # group by version
     for commit in commits:
         # make a new version if required
-        if len(commit['tags']) > 0 or len(versions) == 0:
-            tag = commit['tags'][0] if len(commit['tags']) > 0 else 'HEAD'
-            versions.append(Version(ref=tag, date=commit['date']))
+        if len(commit['tags']) > 0 and _is_valid_version(
+            commit['tags'][0], prefix=prefix
+        ):
+            versions.append(Version(ref=commit['tags'][0], date=commit['date']))
+        elif len(versions) == 0:
+            versions.append(Version(ref='HEAD', date=commit['date']))
 
         this_commit = Commit(commit)
 
@@ -232,11 +266,24 @@ def update_latest_version(versions, prefix=""):
     return versions
 
 
-def format_log(versions, emoji=False):
-    """Produce a nicely formatted changelog - with emoji too if required."""
+def override_latest_version(versions, overriding, prefix=""):
+    """Update the HEAD reference to show the overriding version."""
+    latest_version = versions[0]
+    latest_version.ref = f"{prefix}{overriding}"
+
+    return versions
+
+
+def format_log(versions, emoji=False, development=False):
+    """
+    Produce a nicely formatted changelog - with emoji too if required.
+
+    Always includes production headings.
+    Includes additional headings if development is `True`.
+    """
     output = "# Changelog"
 
-    headings = {
+    production_headings = {
         'docs': "Docs 📝",
         'feat': "Features ✨",
         'fix': "Fixes 🐛",
@@ -245,6 +292,19 @@ def format_log(versions, emoji=False):
         'other': "Other 🃏",
     }
 
+    development_headings = {
+        'ci': "Continuous Integration 🤖",
+        'revert': "Reverted ☠️",
+        'test': "Testing 🧪",
+    }
+
+    if development is True:
+        # combine both heading dictionaries into one
+        headings = {**production_headings, **development_headings}
+    else:
+        # use only the production headings
+        headings = production_headings
+
     if not emoji:
         # remove emoji (first two characters) from headings, and strip space character
         headings = {key: heading[:-2].strip() for key, heading in headings.items()}
@@ -258,8 +318,8 @@ def format_log(versions, emoji=False):
         # store groupby results as lists
         groups = []
         uniquekeys = []
-        data = sorted(version.commits, key=lambda x: x.type[:4])
-        for k, g in groupby(data, lambda x: x.type):
+        data = sorted(version.commits, key=lambda x: x.commit_type[:4])
+        for k, g in groupby(data, lambda x: x.commit_type):
             groups.append(list(g))  # Store group iterator as a list
             uniquekeys.append(k)
 
